@@ -15,7 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import os
-from unittest import main, TestLoader
+import unittest
 
 import fixtures
 import psycopg2
@@ -28,10 +28,10 @@ from pgbouncer.fixture import PGBouncerFixture
 # A 'just-works' workaround for Ubuntu not exposing initdb to the main PATH.
 os.environ['PATH'] = os.environ['PATH'] + ':/usr/lib/postgresql/8.4/bin'
 
+
 def test_suite():
-    result = testresources.OptimisingTestSuite()
-    result.addTest(TestLoader().loadTestsFromName(__name__))
-    return result
+    loader = testresources.TestLoader()
+    return loader.loadTestsFromName(__name__)
 
 
 class ResourcedTestCase(testtools.TestCase, testresources.ResourcedTestCase):
@@ -49,15 +49,21 @@ class TestFixture(ResourcedTestCase):
 
     resources = [('db', DatabaseManager(initialize_sql=setup_user))]
 
+    def setUp(self):
+        super(TestFixture, self).setUp()
+        self.bouncer = PGBouncerFixture()
+        self.bouncer.databases[self.db.database] = 'host=' + self.db.host
+        self.bouncer.users['user1'] = ''
+
+    def connect(self, host=None):
+        return psycopg2.connect(
+            host=(self.bouncer.host if host is None else host),
+            port=self.bouncer.port, database=self.db.database,
+            user='user1')
+
     def test_dynamic_port_allocation(self):
-        bouncer = PGBouncerFixture()
-        db = self.db
-        bouncer.databases[db.database] = 'host=%s' % (db.host,)
-        bouncer.users['user1'] = ''
-        with bouncer:
-            conn = psycopg2.connect(host=bouncer.host, port=bouncer.port,
-                user='user1', database=db.database)
-            conn.close()
+        self.useFixture(self.bouncer)
+        self.connect().close()
 
     def test_stop_start_facility(self):
         # Once setup the fixture can be stopped, and started again, retaining
@@ -65,36 +71,21 @@ class TestFixture(ResourcedTestCase):
         # potentially be used by a different process, so this isn't perfect,
         # but its pretty reliable as a test helper, and manual port allocation
         # outside the dynamic range should be fine.
-        bouncer = PGBouncerFixture()
-        db = self.db
-        bouncer.databases[db.database] = 'host=%s' % (db.host,)
-        bouncer.users['user1'] = ''
-        def check_connect():
-            conn = psycopg2.connect(host=bouncer.host, port=bouncer.port,
-                user='user1', database=db.database)
-            conn.close()
-        with bouncer:
-            current_port = bouncer.port
-            bouncer.stop()
-            self.assertRaises(psycopg2.OperationalError, check_connect)
-            bouncer.start()
-            check_connect()
+        self.useFixture(self.bouncer)
+        self.bouncer.stop()
+        self.assertRaises(psycopg2.OperationalError, self.connect)
+        self.bouncer.start()
+        self.connect().close()
 
     def test_unix_sockets(self):
-        db = self.db
         unix_socket_dir = self.useFixture(fixtures.TempDir()).path
-        bouncer = PGBouncerFixture()
-        bouncer.databases[db.database] = 'host=%s' % (db.host,)
-        bouncer.users['user1'] = ''
-        bouncer.unix_socket_dir = unix_socket_dir
-        with bouncer:
-            # Connect to pgbouncer via a Unix domain socket. We don't
-            # care how pgbouncer connects to PostgreSQL.
-            conn = psycopg2.connect(
-                host=unix_socket_dir, user='user1',
-                database=db.database, port=bouncer.port)
-            conn.close()
+        self.bouncer.unix_socket_dir = unix_socket_dir
+        self.useFixture(self.bouncer)
+        # Connect to pgbouncer via a Unix domain socket. We don't
+        # care how pgbouncer connects to PostgreSQL.
+        self.connect(host=unix_socket_dir).close()
 
 
 if __name__ == "__main__":
-    main(testLoader=TestLoader())
+    loader = testresources.TestLoader()
+    unittest.main(testLoader=loader)
